@@ -1,6 +1,6 @@
 package Proc::tored::Pool;
 # ABSTRACT: managed work pool with Proc::tored and Parallel::ForkManager
-$Proc::tored::Pool::VERSION = '0.02';
+$Proc::tored::Pool::VERSION = '0.03';
 
 use strict;
 use warnings;
@@ -33,7 +33,6 @@ sub on       ($@)   { 'on_' . shift, @_ }
 sub call     (&@)   { @_ }
 sub pending  ($)    { $_[0]->pending }
 sub sync     ($)    { $_[0]->sync }
-#sub process  (&$;$) { $_[1]->assign($_[0], $_[2]) };
 
 sub process (&$;$) {
   my $code = shift;
@@ -56,7 +55,7 @@ Proc::tored::Pool - managed work pool with Proc::tored and Parallel::ForkManager
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -80,7 +79,11 @@ version 0.02
   } $pool;
 
   # Control the pool as a Proc::tored service
+  pause $pool;
+  resume $pool;
+  stop $pool;
   zap $pool, 15 or die "timed out after 15 seconds waiting for pool to stop";
+  start $pool;
 
 =head1 DESCRIPTION
 
@@ -187,14 +190,29 @@ error message generated by the code ref.
 
 =head1 BUGS AND LIMITATIONS
 
-The same warnings and limitations pertain to C<Proc::tored::Pool> as apply to
-L<Parallel::ForkManager>, including an injunction against using two pools
-simultaneously from the same process. See L<Parallel::ForkManager/BUGS AND
-LIMITATIONS> and L<Parallel::ForkManager/SECURITY> for details.
+=head2 Proc::tored
+
+Warnings and limitations for L<Proc::tored> also apply to this module,
+especially the notes regarding service control from within a running service
+which also apply to code executing in forked worker processes. See
+L<Proc::tored/BUGS AND LIMITATIONS> for details.
+
+=head2 Parallel::ForkManager
+
+Warnings and limitations for L<Parallel::ForkManager> also apply to this
+module, including the injunction against using two pools simultaneously from
+the same process. See L<Parallel::ForkManager/BUGS AND LIMITATIONS> and
+L<Parallel::ForkManager/SECURITY> for details.
 
 =head1 SEE ALSO
 
-L<Proc::tored>, L<Parallel::ForkManager>
+=over
+
+=item L<Proc::tored>
+
+=item L<Parallel::ForkManager>
+
+=back
 
 =head1 AUTHOR
 
